Index: include/core/SkCanvas.h |
diff --git a/include/core/SkCanvas.h b/include/core/SkCanvas.h |
index dc3953ed4b1df71634992a1bec5bd1d7a85450e3..d0b8fc94be4c3679ed14fc0abfde96e51330660d 100644 |
--- a/include/core/SkCanvas.h |
+++ b/include/core/SkCanvas.h |
@@ -57,7 +57,7 @@ public: |
*/ |
explicit SkCanvas(SkBaseDevice* device); |
- /** Deprecated - Construct a canvas with the specified bitmap to draw into. |
+ /** Construct a canvas with the specified bitmap to draw into. |
@param bitmap Specifies a bitmap for the canvas to draw into. Its |
structure are copied to the canvas. |
*/ |
@@ -942,11 +942,10 @@ public: |
*/ |
ClipType getClipType() const; |
/** Return the current device clip (concatenation of all clip calls). |
* This does not account for the translate in any of the devices. |
* @return the current device clip (concatenation of all clip calls). |
- * |
- * DEPRECATED -- call getClipDeviceBounds() instead. |
*/ |
const SkRegion& getTotalClip() const; |
@@ -1034,8 +1033,8 @@ protected: |
// can perform copy-on-write or invalidate any cached images |
void predrawNotify(); |
- /** DEPRECATED -- use constructor(device) |
- |
+ /** |
+ DEPRECATED -- need to remove when subclass stop relying on it. |
Marked as 'protected' to avoid new clients using this before we can |
completely remove it. |
@@ -942,11 +942,10 @@ public: |
*/ |
ClipType getClipType() const; |
- /** Return the current device clip (concatenation of all clip calls). |
+ /** DEPRECATED -- need to move this guy to private/friend |
+ * Return the current device clip (concatenation of all clip calls). |
* This does not account for the translate in any of the devices. |
* @return the current device clip (concatenation of all clip calls). |